##
##  scponly.spec -- OpenPKG RPM Package Specification
##  Copyright (c) 2000-2010 OpenPKG Foundation e.V. <http://openpkg.net/>
##
##  Permission to use, copy, modify, and distribute this software for
##  any purpose with or without fee is hereby granted, provided that
##  the above copyright notice and this permission notice appear in all
##  copies.
##
##  THIS SOFTWARE IS PROVIDED ``AS IS'' AND ANY EXPRESSED OR IMPLIED
##  WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED WARRANTIES OF
##  MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE DISCLAIMED.
##  IN NO EVENT SHALL THE AUTHORS AND COPYRIGHT HOLDERS AND THEIR
##  CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL,
##  SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT
##  LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF
##  USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND
##  ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY,
##  OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT
##  OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF
##  SUCH DAMAGE.
##

#   package information
Name:         scponly
Summary:      Secure Shell (SSH) Wrapper for SCP/SFTP Access Only
URL:          http://sublimation.org/scponly/
Vendor:       Joe Boyle
Packager:     OpenPKG Foundation e.V.
Distribution: OpenPKG Community
Class:        PLUS
Group:        SSH
License:      MIT-style
Version:      4.8
Release:      20101209

#   package options
%option       with_fsl     yes
%option       with_chroot  no

#   list of sources
Source0:      http://switch.dl.sourceforge.net/scponly/scponly-%{version}.tgz
Source1:      rc.scponly
Source2:      fsl.scponly
Patch0:       scponly.patch

#   build information
BuildPreReq:  OpenPKG, openpkg >= 20100101, make, gcc
PreReq:       OpenPKG, openpkg >= 20100101, openssh
%if "%{with_fsl}" == "yes"
BuildPreReq:  fsl
PreReq:       fsl
%endif

%description
    scponly is an alternative login shell for providing restricted
    access to remote users to both read and write local files via
    SCP and SFTP only and without providing any remote execution
    privileges.

%track
    prog scponly = {
        version   = %{version}
        url       = http://sublimation.org/scponly/wiki/index.php/Download
        regex     = scponly-(__VER__)\.tgz
    }

%prep
    %setup -q
    %patch -p0
    %{l_shtool} subst -e 's;${DEFS}\(.*\)$;${DEFS} @LDFLAGS@\1 @LIBS@;' Makefile.in

%build
    ( echo "ac_cv_path_scponly_PROG_SFTP_SERVER=%{l_prefix}/libexec/openssh/sftp-server"
      echo "ac_cv_path_scponly_PROG_SCP=%{l_prefix}/bin/scp"
      echo "ac_cv_path_scponly_PROG_RSYNC=%{l_prefix}/bin/rsync"
    ) >config.cache
    CC="%{l_cc}" \
    CFLAGS="%{l_cflags -O}" \
    LDFLAGS="%{l_fsl_ldflags}" \
    LIBS="%{l_fsl_libs}" \
    ./configure \
        --cache-file=./config.cache \
        --prefix=%{l_prefix} \
        --enable-rsync-compat \
%if "%{with_chroot}" == "yes"
        --enable-chrooted-binary \
%endif
        PACKAGE_NAME=scponly
    %{l_make} %{l_mflags -O} all debuglevel

%install
    %{l_shtool} mkdir -f -p -m 755 \
        $RPM_BUILD_ROOT%{l_prefix}/var/scponly \
        $RPM_BUILD_ROOT%{l_prefix}/etc/scponly \
        $RPM_BUILD_ROOT%{l_prefix}/bin \
        $RPM_BUILD_ROOT%{l_prefix}/man/man8
    %{l_shtool} install -c -s -m 755 \
        scponly $RPM_BUILD_ROOT%{l_prefix}/bin/
    %{l_shtool} install -c -m 644 \
        scponly.8 $RPM_BUILD_ROOT%{l_prefix}/man/man8/
    %{l_shtool} install -c -m 644 \
        debuglevel $RPM_BUILD_ROOT%{l_prefix}/etc/scponly/

    #   install scponlyc if building with chroot environment
%if "%{with_chroot}" == "yes"
    %{l_shtool} mkdir -f -p -m 755 \
        $RPM_BUILD_ROOT%{l_prefix}/sbin
    %{l_shtool} install -c -s -m 755 \
        scponly $RPM_BUILD_ROOT%{l_prefix}/sbin/scponlyc
%endif

    #   install run-command script
    %{l_shtool} mkdir -f -p -m 755 \
        $RPM_BUILD_ROOT%{l_prefix}/etc/rc.d
    %{l_shtool} install -c -m 755 %{l_value -s -a} \
        %{SOURCE rc.scponly} $RPM_BUILD_ROOT%{l_prefix}/etc/rc.d/

    #   install OSSP fsl configuration
    %{l_shtool} mkdir -f -p -m 755 $RPM_BUILD_ROOT%{l_prefix}/etc/fsl
    %{l_shtool} install -c -m 644 %{l_value -s -a} \
        %{SOURCE fsl.scponly} \
        $RPM_BUILD_ROOT%{l_prefix}/etc/fsl/

    #   determine installation files
    %{l_rpmtool} files -v -ofiles -r$RPM_BUILD_ROOT \
        %{l_files_std} \
%if "%{with_chroot}" == "yes"
        '%attr(4555,%{l_susr},%{l_mgrp}) %{l_prefix}/sbin/scponlyc' \
%endif
        '%config %{l_prefix}/etc/fsl/fsl.scponly' \
        '%config %{l_prefix}/etc/scponly/*' \
        '%attr(1777,%{l_musr},%{l_mgrp}) %{l_prefix}/var/scponly'

%files -f files

%clean

